Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(497)

Unified Diff: third_party/WebKit/Source/modules/fetch/DataConsumerTee.cpp

Issue 2104913002: Rename threadSafeBind() to crossThreadBind() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@TRV_CTCPointer
Patch Set: Rebase Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/fetch/DataConsumerTee.cpp
diff --git a/third_party/WebKit/Source/modules/fetch/DataConsumerTee.cpp b/third_party/WebKit/Source/modules/fetch/DataConsumerTee.cpp
index 535205629d7450a78776effa97595faadbeee306..a30dd8016c7c30a69b022ec2aa142202645ebffa 100644
--- a/third_party/WebKit/Source/modules/fetch/DataConsumerTee.cpp
+++ b/third_party/WebKit/Source/modules/fetch/DataConsumerTee.cpp
@@ -8,7 +8,7 @@
#include "core/dom/ExecutionContext.h"
#include "modules/fetch/DataConsumerHandleUtil.h"
#include "modules/fetch/FetchBlobDataConsumerHandle.h"
-#include "platform/ThreadSafeFunctional.h"
+#include "platform/CrossThreadFunctional.h"
#include "platform/heap/Handle.h"
#include "public/platform/Platform.h"
#include "public/platform/WebTaskRunner.h"
@@ -185,7 +185,7 @@ public:
}
ASSERT(m_readerThread);
if (!m_readerThread->isCurrentThread()) {
- m_readerThread->getWebTaskRunner()->postTask(BLINK_FROM_HERE, threadSafeBind(&DestinationContext::notify, wrapPassRefPtr(this)));
+ m_readerThread->getWebTaskRunner()->postTask(BLINK_FROM_HERE, crossThreadBind(&DestinationContext::notify, wrapPassRefPtr(this)));
return;
}
}
@@ -269,10 +269,10 @@ public:
MutexLocker locker(context()->mutex());
context()->attachReader(client);
if (client) {
// We need to use threadSafeBind here to retain the context. Note
// |context()| return value is of type DestinationContext*, not
// PassRefPtr<DestinationContext>.
- Platform::current()->currentThread()->getWebTaskRunner()->postTask(BLINK_FROM_HERE, threadSafeBind(&DestinationContext::notify, wrapPassRefPtr(context())));
+ Platform::current()->currentThread()->getWebTaskRunner()->postTask(BLINK_FROM_HERE, crossThreadBind(&DestinationContext::notify, wrapPassRefPtr(context())));
}
}
~DestinationReader() override
@@ -269,10 +269,10 @@ public:
context()->attachReader(client);
if (client) {
- // We need to use threadSafeBind here to retain the context. Note
+ // We need to use crossThreadBind here to retain the context. Note
// |context()| return value is of type DestinationContext*, not
// PassRefPtr<DestinationContext>.

Powered by Google App Engine
This is Rietveld 408576698